@@ -836,7 +836,9 @@ return;
 return;
 		}
 		binaryCreateEditor(tab,tfv);
-	    } else
+	    } else if(k==-1)
+		binaryCreateEditor(tab,tfv);
+	    else
 		(tableinfo[k].createviewer)(tab,tfv);
 	}
     } else if ( e->type == et_mouseup ) {
